package jalview.gui;

import java.awt.*;
import java.awt.Graphics2D.*;

import javax.swing.*;
import jalview.datamodel.*;
import jalview.analysis.*;
public class IdCanvas extends JPanel
{
  protected AlignViewport av;

  protected boolean showScores  = true;

  protected int     maxIdLength = -1;
  protected String  maxIdStr    = null;

  public IdCanvas(AlignViewport av)
  {
    setLayout(new BorderLayout());
    this.av         = av;
    PaintRefresher.Register(this);
  }

  public void drawIdString(Graphics gg,SequenceI s,int i, int starty, int ypos) {
      int charHeight = av.getCharHeight();


      if (av.getSelectionGroup()!=null && av.getSelectionGroup().sequences.contains(s)) {
	  gg.setColor(Color.lightGray);
	  gg.fillRect(0,AlignmentUtil.getPixelHeight(starty,i,charHeight)+ ypos,getWidth(),charHeight);
	  gg.setColor(Color.white);
      } else {
	  gg.setColor(s.getColor());
	  gg.fillRect(0,AlignmentUtil.getPixelHeight(starty,i,charHeight)+ ypos,getWidth(),charHeight);
	  gg.setColor(Color.black);
      }

      String string = s.getName();
      if(av.getShowFullId())
        string = s.getDisplayId();

      gg.drawString(string,0,AlignmentUtil.getPixelHeight(starty,i,charHeight) + ypos + charHeight-   (charHeight/5));

  }

  public void paintComponent(Graphics g) {
    Graphics2D gg = (Graphics2D)g;
    gg.setRenderingHint(RenderingHints.KEY_ANTIALIASING,RenderingHints.VALUE_ANTIALIAS_ON);
    AlignmentI al         = av.alignment;
    int        charHeight = av.charHeight;
    Font italic = new Font(av.getFont().getName(), Font.ITALIC, av.getFont().getSize());

    gg.setFont(italic);


    //Fill in the background
    gg.setColor(Color.white);
    gg.fillRect(0,0,getWidth(),getHeight());

    Color currentColor     = Color.white;
    Color currentTextColor = Color.black;

    //Which ids are we printing
    int starty = av.getStartSeq();
    int endy   = av.endSeq;

    if (av.getWrapAlignment())
    {
          // Draw the rest of the panels
          int chunkHeight =  (al.getHeight() + 2)*av.charHeight;
          int row = av.getStartRes() / av.chunkWidth ;
          for(int ypos=2*av.charHeight;
              ypos <= getHeight() && row*av.chunkWidth<al.getWidth();
              ypos += chunkHeight, row++ )
          {
            for (int i = starty; i < av.alignment.getHeight(); i++)
            {
              SequenceI s = al.getSequenceAt(i);
              drawIdString(gg, s, i, 0, ypos);
            }
          }


    } else
    {

      //Now draw the id strings
      for (int i = starty; i < endy; i++)
      {
        // Selected sequence colours

        if (av.getSelectionGroup()!= null && av.getSelectionGroup().sequences.contains(al.getSequenceAt(i)))
        {
       //   if(av.alignment.findGroup(al.getSequenceAt(i)).getEndRes()==
          currentColor = Color.lightGray;
          currentTextColor = Color.black;
        }
        else
        {
          currentColor = al.getSequenceAt(i).getColor();
          currentTextColor = Color.black;
        }

        gg.setColor(currentColor);

        gg.fillRect(0,
                    AlignmentUtil.getPixelHeight(starty, i, charHeight),
                    getWidth(),
                    charHeight);

        gg.setColor(currentTextColor);
        String string = al.getSequenceAt(i).getName();
        if(av.getShowFullId())
          string = al.getSequenceAt(i).getDisplayId();
        gg.drawString(string, 0,
                      AlignmentUtil.getPixelHeight(starty, i, charHeight) +
                      charHeight - (charHeight / 5));
      }

      // add a border
      gg.setColor(Color.white);
      gg.fillRect(getWidth()-4,0,4,getHeight());
    }

  }
}
